# Getting help with py-ballisticcalc

If you need help getting started with **py-ballisticcalc** or with advanced usage, the following sources may be useful.

## :material-help: Usage Documentation

The [usage documentation](concepts/munition/weapon.md) is the most complete guide on how to use **py-ballisticcalc**.

[//]: # (## :material-api: API Documentation)

[//]: # ()
[//]: # (The [API documentation]&#40;api/core.md&#41; give reference docs for all public py-ballisticcalc APIs.)

## :simple-github: GitHub Discussions

[GitHub discussions](https://github.com/o-murphy/py-ballisticcalc/discussions) are useful for asking questions, your question and the answer will help everyone.
